#
# spec file for package python-msrest
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-msrest
Version:        0.7.1
Release:        3.5
Summary:        AutoRest swagger generator Python client runtime
License:        MIT
Group:          Development/Languages/Python
URL:            https://pypi.python.org/pypi/msrest
Source:         https://files.pythonhosted.org/packages/source/m/msrest/msrest-%{version}.zip
Source1:        LICENSE.md
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-azure-core >= 1.24.0
Requires:       python-certifi >= 2017.4.17
Requires:       python-isodate >= 0.6.0
Requires:       python-requests-oauthlib >= 0.5.0
Requires:       (python-requests >= 2.16 with python-requests < 3.00)
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-msrest < 0.7.1
%endif
BuildArch:      noarch

%python_subpackages

%description
AutoRest swagger generator Python client runtime
Swagger is a powerful open source framework: http://swagger.io

%prep
%setup -q -n msrest-%{version}
cp %{SOURCE1} LICENSE.md

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc README.rst
%license LICENSE.md
%{python_sitelib}/msrest
%{python_sitelib}/msrest-%{version}*-info

%changelog
* Thu Apr  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Add Obsoletes for old python3 package on SLE-15
  + Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
- Drop setting default file attributes in %%files section
- Use modern RPM macros to express version dependencies
* Fri Mar  1 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Drop definition of BuildRoot
- Drop support for older Python versions
- Limit Python files matched in %%files section
* Mon Aug 15 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.7.1
  + For detailed information about changes see the
    README.rst file provided with this package
- Switch source archive format to ZIP
- Update Requires from setup.py
* Mon Mar 29 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.6.21
  + For detailed information about changes see the
    README.rst file provided with this package
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Tue Oct  6 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.6.19
  + For detailed information about changes see the
    README.rst file provided with this package
* Fri Aug 28 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.6.18
  + For detailed information about changes see the
    README.rst file provided with this package
* Tue Jun 16 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.6.16
  + For detailed information about changes see the
    README.rst file provided with this package
* Tue Mar 31 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.6.11
  + For detailed information about changes see the
    README.rst file provided with this package
* Fri Oct  4 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.6.10
  + For detailed information about changes see the
    README.rst file provided with this package
- Drop patches to support older versions of setuptools as
  SLE-12 is now shipping with a recent enough version
  + m_drop-compatible-releases-operator.patch
  + m_drop-extras-require.patch
* Mon Apr 15 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.6.6
  + No upstream changelog provided
- Refresh patches for new version
  + m_drop-compatible-releases-operator.patch
  + m_drop-extras-require.patch
- Remove python-devel package from BuildRequires
- Add %%python_expand to %%fdupes invocation
* Thu Sep  6 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.5.0
  + No upstream changelog provided
- Add LICENSE.md and install into %%license directory
- Add python-enum34 to Requires for Python 2.x and Python 3.4
- Add python-typing to Requires for Python Python 2x., 3.4 and 3.5
- Refresh patches for new version
  + m_drop-compatible-releases-operator.patch
  + m_drop-extras-require.patch
- Update Requires from setup.py
* Tue Apr 24 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.4.28
  + For detailed information about changes see the
    README.rst file provided with this package
- Refresh patches for new version
  + m_drop-compatible-releases-operator.patch
  + m_drop-extras-require.patch
- Update Requires from setup.py
* Mon Jan 29 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.4.25
- Update Requires from setup.py
* Tue Sep 19 2017 adrian.glaubitz@suse.com
- Add patch to drop compatible releases operator from setup.py,
  required for SLES12 as the setuptools version is too old
  + m_drop-compatible-releases-operator.patch
- Add patch to extras_require field from setup.py, required
  for SLES12 as the setuptools version is too old
  + m_drop-extras-require.patch
* Mon Jul 10 2017 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.4.11
- Provide full source URL in Source field
- Convert package to single spec
- Remove python-enum34 from Requires
* Mon Dec 12 2016 ms@suse.com
- Include in SLE 12 (fate#322171, bsc#1014478)
* Mon Dec 12 2016 ms@suse.com
- Initial build
  + Version 0.4.4
